Skip to contents

theme_doe() uses showtext to allow R graphics devices to render the Public Sans font family. Use check_font_families() to check that Public Sans is available and to activate showtext. If Public Sans is not installed on the system or user font search paths, doestyle's embedded copy of the files will be used.

Usage

check_font_families()

Value

check_font_families() does not have a return value and is called for its side effects.