Activate showtext and check for presence of Public Sans font family
Source: R/load_showtext.R
check_font_families.Rdtheme_doe() uses showtext to allow R graphics devices to render the
Public Sans font family. Use check_font_families() to check that Public
Sans is available and to activate showtext. If Public Sans is not installed
on the system or user font search paths, doestyle's embedded copy of the
files will be used.